<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="100px">
      <el-form-item label="运维人员编号" prop="ywPersonCode">
        <el-input
          v-model="queryParams.ywPersonCode"
          placeholder="请输入运维人员编号"
          clearable
          @clear="handleQuery"
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="运维人员姓名" prop="ywPersonName">
        <el-input
          v-model="queryParams.ywPersonName"
          placeholder="请输入运维人员姓名"
          clearable
          @clear="handleQuery"
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="所属运维单位" prop="belongUnit">
        <el-select v-model="queryParams.belongUnit" @change="handleQuery" clearable placeholder="所属运维单位">
          <el-option
            v-for="item in unitList"
            :key="item.id"
            :label="item.value"
            :value="item.id">
          </el-option>
        </el-select>
      </el-form-item>
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="small" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="small" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['unit:people:add']"
        >新增</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="success"
          plain
          icon="el-icon-edit"
          size="mini"
          :disabled="single"
          @click="handleUpdate"
          v-hasPermi="['unit:people:edit']"
        >修改</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
          v-hasPermi="['unit:people:remove']"
        >删除</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="warning"
          plain
          icon="el-icon-download"
          size="mini"
          @click="handleExport"
          v-hasPermi="['unit:people:export']"
        >导出</el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="peopleList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center" />
      <el-table-column label="运维人员编号" align="center" prop="ywPersonCode" />
      <el-table-column label="运维人员姓名" align="center" prop="ywPersonName" />
      <el-table-column label="运维人员账号" align="center" prop="ywPersonAccount" />
      <el-table-column label="所属运维单位" align="center" prop="belongUnitName" />
      <el-table-column label="联系电话" align="center" prop="phone" />
      <el-table-column label="备注" align="center" prop="remark" show-overflow-tooltip/>
      <el-table-column label="操作" fixed="right" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['unit:people:edit']"
          >修改</el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['unit:people:remove']"
          >删除</el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 添加或修改运维人员对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="100px">
        <el-form-item label="人员编号" prop="ywPersonCode">
          <el-input v-model="form.ywPersonCode" placeholder="请输入运维人员编号" />
        </el-form-item>
        <el-form-item label="人员姓名" prop="ywPersonName">
          <el-input v-model="form.ywPersonName" placeholder="请输入运维人员姓名" />
        </el-form-item>
        <el-form-item label="人员账号" prop="ywPersonAccount">
          <el-input v-model="form.ywPersonAccount" placeholder="请输入运维人员账号" />
        </el-form-item>
        <el-form-item label="所属单位" prop="belongUnit">
          <el-select v-model="form.belongUnit" placeholder="所属运维单位">
            <el-option
              v-for="item in unitList"
              :key="item.id"
              :label="item.value"
              :value="item.id">
            </el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="联系电话" prop="phone">
          <el-input v-model="form.phone" placeholder="请输入联系电话" />
        </el-form-item>
        <el-form-item label="联系电话" prop="remark">
          <el-input v-model="form.remark" type="textarea" show-word-limit maxlength="150" placeholder="请输入备注" />
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button @click="cancel">取 消</el-button>
        <el-button type="primary" @click="submitForm">确 定</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import { listPeople, getPeople, delPeople, addPeople, updatePeople } from "@/api/platform/people";
import { unitSelect } from "@/api/platform/unit";

export default {
  name: "People",
  data() {
    return {
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 运维人员表格数据
      peopleList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        ywPersonCode: null,
        ywPersonName: null,
        belongUnit: null,
      },
      // 运维单位
      unitList: [],
      // 表单参数
      form: {},
      // 表单校验
      rules: {
        ywPersonCode: [
          { required: true, message: "运维人员编号不能为空", trigger: "blur" }
        ],
        ywPersonName: [
          { required: true, message: "运维人员姓名不能为空", trigger: "blur" }
        ],
        ywPersonAccount: [
          { required: true, message: "运维人员账号不能为空", trigger: "blur" }
        ],
        belongUnit: [
          { required: true, message: "所属运维单位不能为空", trigger: "blur" }
        ],
        phone: [
          { required: true, message: "联系电话不能为空", trigger: "blur" }
        ],
      }
    };
  },
  created() {
    this.getList();
    this.getUnitSelect()
  },
  methods: {
    getUnitSelect() {
      // 运维单位下拉列表
      unitSelect().then((res) => {
        this.unitList = res.data;
      })
    },

    /** 查询运维人员分页 */
    getList() {
      this.loading = true;
      listPeople(this.queryParams).then(response => {
        this.peopleList = response.data;
        this.total = response.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        id: null,
        ywPersonCode: null,
        ywPersonName: null,
        ywPersonAccount: null,
        belongUnit: null,
        addWay: null,
        phone: null,
        createTime: null,
        updateTime: null,
        deleted: null
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.id)
      this.single = selection.length!==1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加运维人员";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const id = row.id || this.ids
      getPeople(id).then(response => {
        this.form = response.data;
        this.open = true;
        this.title = "修改运维人员";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate(valid => {
        if (valid) {
          if (this.form.id != null) {
            updatePeople(this.form).then(response => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addPeople(this.form).then(response => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids;
      this.$modal.confirm('是否确认删除运维人员编号为"' + ids + '"的数据项？').then(function() {
        return delPeople(ids);
      }).then(() => {
        this.getList();
        this.$modal.msgSuccess("删除成功");
      }).catch(() => {});
    },
    /** 导出按钮操作 */
    handleExport() {
      this.download('system/people/export', {
        ...this.queryParams
      }, `people_${new Date().getTime()}.xlsx`)
    }
  }
};
</script>
